==> LLTestJavaSDK-0.0.4-sources.jar: io/github/kaposke/models/CreateApiRequest.java <==
package io.github.kaposke.models;

@lombok.Getter
@lombok.EqualsAndHashCode(callSuper = false)
@lombok.ToString
@com.fasterxml.jackson.annotation.JsonInclude(
  com.fasterxml.jackson.annotation.JsonInclude.Include.NON_NULL
)
@com.fasterxml.jackson.databind.annotation.JsonDeserialize(builder = CreateApiRequest.Builder.class)
public class CreateApiRequest extends io.github.kaposke.models.BaseModel {

  @lombok.Getter
  @lombok.Setter
  @lombok.experimental.Accessors(chain = true)
  @com.fasterxml.jackson.databind.annotation.JsonPOJOBuilder(
    buildMethodName = "buildWithoutValidation",
    withPrefix = "set"
  )
  public static class Builder extends io.github.kaposke.models.BaseModel.Builder {

    static final java.util.Set<java.util.Set<String>> REQUIRED_FIELDS_GROUPS;

    static {
      java.lang.String[][] requiredFieldsGroups = new java.lang.String[][] {
        new java.lang.String[] { "name", "orgId", "version" },
      };

      REQUIRED_FIELDS_GROUPS =
        java.util.Arrays
          .stream(requiredFieldsGroups)
          .map(group -> java.util.Arrays.stream(group).collect(java.util.stream.Collectors.toSet()))
          .collect(java.util.stream.Collectors.toSet());
    }

    @com.fasterxml.jackson.annotation.JsonProperty("name")
    private java.lang.String name;

    @com.fasterxml.jackson.annotation.JsonProperty("orgId")
    private java.lang.Double orgId;

    @com.fasterxml.jackson.annotation.JsonProperty("version")
    private java.lang.String version;

    public Builder() {
      super(ValidationType.ALL_OF);
    }

    protected Builder(BaseModel.Builder.ValidationType validationType) {
      super(validationType);
    }

    public CreateApiRequest build() {
      String validateMsg = validate();

      if (validateMsg != null) {
        throw new io.github.kaposke.exceptions.ApiException(validateMsg);
      }

      return buildWithoutValidation();
    }

    public CreateApiRequest buildWithoutValidation() {
      return new CreateApiRequest(this);
    }

    @Override
    protected java.util.Set<String> getNonNullInstanceFieldNames() {
      // Introspect the class to get a list of all declared fields.
      return java.util.Arrays
        .stream(this.getClass().getDeclaredFields())
        .filter(field -> {
          try {
            // Filter fields that are non-static and have values that are not null.
            return (
              !java.lang.reflect.Modifier.isStatic(field.getModifiers()) && field.get(this) != null
            );
          } catch (IllegalArgumentException | IllegalAccessException e) {
            // This should never happen...

            throw new io.github.kaposke.exceptions.ApiException(
              "Unexpected exception thrown while accessing instance fields.",
              e
            );
          }
        })
        .map(java.lang.reflect.Field::getName)
        .collect(java.util.stream.Collectors.toSet());
    }

    @Override
    protected java.util.Set<java.util.Set<String>> getRequiredFieldsGroups() {
      return REQUIRED_FIELDS_GROUPS;
    }
  }

  @com.fasterxml.jackson.annotation.JsonProperty("name")
  private final java.lang.String name;

  @com.fasterxml.jackson.annotation.JsonProperty("orgId")
  private final java.lang.Double orgId;

  @com.fasterxml.jackson.annotation.JsonProperty("version")
  private final java.lang.String version;

  CreateApiRequest(Builder builder) {
    super(builder);
    this.name = builder.getName();
    this.orgId = builder.getOrgId();
    this.version = builder.getVersion();
  }
}

==> LLTestJavaSDK-0.0.6-sources.jar: io/github/kaposke/models/CreateApiRequest.java <==
package io.github.kaposke.models;

@lombok.Getter
@lombok.EqualsAndHashCode(callSuper = false)
@lombok.ToString
@com.fasterxml.jackson.annotation.JsonInclude(
  com.fasterxml.jackson.annotation.JsonInclude.Include.NON_NULL
)
@com.fasterxml.jackson.databind.annotation.JsonDeserialize(builder = CreateApiRequest.Builder.class)
public class CreateApiRequest extends io.github.kaposke.models.BaseModel {

  @lombok.Getter
  @lombok.Setter
  @lombok.experimental.Accessors(chain = true)
  @com.fasterxml.jackson.databind.annotation.JsonPOJOBuilder(
    buildMethodName = "buildWithoutValidation",
    withPrefix = "set"
  )
  public static class Builder extends io.github.kaposke.models.BaseModel.Builder {

    static final java.util.Set<java.util.Set<String>> REQUIRED_FIELDS_GROUPS;

    static {
      java.lang.String[][] requiredFieldsGroups = new java.lang.String[][] {
        new java.lang.String[] { "name", "orgId", "spec", "version" },
      };

      REQUIRED_FIELDS_GROUPS =
        java.util.Arrays
          .stream(requiredFieldsGroups)
          .map(group -> java.util.Arrays.stream(group).collect(java.util.stream.Collectors.toSet()))
          .collect(java.util.stream.Collectors.toSet());
    }

    @com.fasterxml.jackson.annotation.JsonProperty("name")
    private java.lang.String name;

    @com.fasterxml.jackson.annotation.JsonProperty("orgId")
    private java.lang.Double orgId;

    @com.fasterxml.jackson.annotation.JsonProperty("spec")
    private java.lang.String spec;

    @com.fasterxml.jackson.annotation.JsonProperty("version")
    private java.lang.String version;

    public Builder() {
      super(ValidationType.ALL_OF);
    }

    protected Builder(BaseModel.Builder.ValidationType validationType) {
      super(validationType);
    }

    public CreateApiRequest build() {
      String validateMsg = validate();

      if (validateMsg != null) {
        throw new io.github.kaposke.exceptions.ApiException(validateMsg);
      }

      return buildWithoutValidation();
    }

    public CreateApiRequest buildWithoutValidation() {
      return new CreateApiRequest(this);
    }

    @Override
    protected java.util.Set<String> getNonNullInstanceFieldNames() {
      // Introspect the class to get a list of all declared fields.
      return java.util.Arrays
        .stream(this.getClass().getDeclaredFields())
        .filter(field -> {
          try {
            // Filter fields that are non-static and have values that are not null.
            return (
              !java.lang.reflect.Modifier.isStatic(field.getModifiers()) && field.get(this) != null
            );
          } catch (IllegalArgumentException | IllegalAccessException e) {
            // This should never happen...

            throw new io.github.kaposke.exceptions.ApiException(
              "Unexpected exception thrown while accessing instance fields.",
              e
            );
          }
        })
        .map(java.lang.reflect.Field::getName)
        .collect(java.util.stream.Collectors.toSet());
    }

    @Override
    protected java.util.Set<java.util.Set<String>> getRequiredFieldsGroups() {
      return REQUIRED_FIELDS_GROUPS;
    }
  }

  @com.fasterxml.jackson.annotation.JsonProperty("name")
  private final java.lang.String name;

  @com.fasterxml.jackson.annotation.JsonProperty("orgId")
  private final java.lang.Double orgId;

  @com.fasterxml.jackson.annotation.JsonProperty("spec")
  private final java.lang.String spec;

  @com.fasterxml.jackson.annotation.JsonProperty("version")
  private final java.lang.String version;

  CreateApiRequest(Builder builder) {
    super(builder);
    this.name = builder.getName();
    this.orgId = builder.getOrgId();
    this.spec = builder.getSpec();
    this.version = builder.getVersion();
  }
}
